@@ -403,6 +403,35 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyRecordsStatus(self, request):
+        """This API is used to modify the DNS record status.
+
+        :param request: Request instance for ModifyRecordsStatus.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.ModifyRecordsStatusRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.ModifyRecordsStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyRecordsStatus", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyRecordsStatusResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SubscribePrivateZoneService(self, request):
         """This API is used to activate the Private DNS service.
 
